@@ -711,10 +711,8 @@ attach_to_conv(PurpleConversation *conv, gpointer null)
 {
     PidginConversation *gtkconv = PIDGIN_CONVERSATION(conv);
     GtkWidget *box, *sep, *counter, *menus;
-    GtkIMHtml *imhtml;
 
     box = gtkconv->toolbar;
-    imhtml = GTK_IMHTML(gtkconv->imhtml);
 
     /* Disable widgets that decorate or add link to composing text
      * because Twitter cannot receive marked up string. For lean-view
@@ -1420,10 +1418,10 @@ static PurplePluginInfo info = {
     PURPLE_PRIORITY_DEFAULT,    /**< priority	*/
     PLUGIN_ID,                  /**< id     */
     "Pidgin-Twitter",           /**< name	*/
-    "0.9.2",                    /**< version	*/
+    "0.9.2.1",                  /**< version	*/
     "provides useful features for twitter", /**  summary	*/
     "provides useful features for twitter", /**  desc	*/
-    "Yoshiki Yazawa, mikanbako, \nKonosuke Watanabe, IWATA Ray, \nmojin, umq, \nthe pidging-twitter team",     /**< author	*/
+    "Yoshiki Yazawa, mikanbako, \nKonosuke Watanabe, IWATA Ray, \nmojin, umq, dai, \nthe pidging-twitter team",     /**< author	*/
     "http://www.honeyplanet.jp/pidgin-twitter/",   /**< homepage	*/
     load_plugin,                /**< load	*/
     unload_plugin,              /**< unload	*/
