@@ -896,17 +896,12 @@ post_status_with_api(PurpleAccount *account, char **buffer)
 {
     char *request, *header;
     const char *url_encoded = g_uri_escape_string(*buffer, "", FALSE);
-    PurpleConversation *conv;
     char *oauth;
     twitter_message_t *tm;
     const char *a_key = NULL;
     const char *a_sec = NULL;
     oauth_request_t oauth_req;
 
-    conv = purple_find_conversation_with_account(
-        PURPLE_CONV_TYPE_ANY, "twitter@twitter.com",
-        account_for_twitter); /* xxx */
-
     a_key = purple_prefs_get_string(OPT_AKEY_TWITTER);
     a_sec = purple_prefs_get_string(OPT_ASEC_TWITTER);
 
@@ -969,14 +964,8 @@ fav_with_api(guint64 id)
     char *oauth;
     const char *a_key = NULL;
     const char *a_sec = NULL;
-    PurpleConversation *conv;
     oauth_request_t oauth_req;
 
-    conv = purple_find_conversation_with_account(PURPLE_CONV_TYPE_ANY,
-                                                 "twitter@twitter.com",
-                                                 account_for_twitter); /* xxx */
-
-
     a_key = purple_prefs_get_string(OPT_AKEY_TWITTER);
     a_sec = purple_prefs_get_string(OPT_ASEC_TWITTER);
 
@@ -1033,13 +1022,8 @@ retweet_with_api(guint64 id)
     char *oauth;
     const char *a_key = NULL;
     const char *a_sec = NULL;
-    PurpleConversation *conv;
     oauth_request_t oauth_req;
 
-    conv = purple_find_conversation_with_account(PURPLE_CONV_TYPE_ANY,
-                                                 "twitter@twitter.com",
-                                                 account_for_twitter); /* xxx */
-
     a_key = purple_prefs_get_string(OPT_AKEY_TWITTER);
     a_sec = purple_prefs_get_string(OPT_ASEC_TWITTER);
 
